@@ -1,16 +1,15 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.20 2008/07/28 04:51:29 bkorb Exp $
+ *  $Id: agUtils.c,v 4.22 2009/07/21 03:21:57 bkorb Exp $
  *
- *  Time-stamp:        "2008-07-26 10:00:15 bkorb"
- *  Last Committed:    $Date: 2008/07/28 04:51:29 $
+ *  Time-stamp:        "2009-07-09 20:18:45 bkorb"
+ *  Last Committed:    $Date: 2009/07/21 03:21:57 $
  *
  *  This is the main routine for autogen.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -54,8 +53,6 @@ strlcpy( char* dest, tCC* src, size_t n )
         }
     }
 
-    assert( sz + (src - ps) == strlen( ps ) + 1 );
-
     return sz + (src - ps);
 }
 #endif
@@ -71,11 +68,9 @@ aprf( char const* pzFmt, ... )
     va_end( ap );
 
     if (pz == NULL) {
-        tSCC zMsg[] = "could not allocate for or formatting failed on:\n";
-        char z[ 256 ];
-        strcpy( z, zMsg );
-        strncpy( z + sizeof( zMsg )-1, pzFmt, sizeof(z) - sizeof(zMsg));
-        z[ sizeof(z)-1 ] = NUL;
+        tSCC zMsg[] = "could not allocate for or formatting failed on:\n%s";
+        char z[ sizeof (zMsg) + SCRIBBLE_SIZE ];
+        snprintf(z, sizeof(z), zMsg, pzFmt);
         AG_ABEND( z );
     }
     return pz;
